@@ -16,7 +16,7 @@
 
         p.setName("Linus Torvalds");
         p.setAddress("E-mail: Torvalds@cs.helsinki.fi");
-        p.setPhone(" - not sure - ");
+        p.setPhone("");
         p.setMass(75);           // kg.
 
         printperson(p);
@@ -26,7 +26,7 @@
 
 Name    : Linus Torvalds
 Address : E-mail: Torvalds@cs.helsinki.fi
-Phone   :  - not sure -
+Phone   :  - not available -
 Mass  : 75
 
 */
