@@ -21,7 +21,7 @@ int main(int argc, char **argv)
     sort(sp.rbegin(), sp.rend());
     copy(sp.begin(), sp.end(), ostream_iterator<string>(cout, " "));
 
-    cout << endl;
+    cout << '\n';
 }
 
     /*
