@@ -19,11 +19,11 @@
     };
     int main()
     {
-        vector<size_t>    uv(10);
+        vector<size_t> uv(10);
 
-        generate_n(uv.begin(), 5, NaturalSquares());
+        generate_n(uv.begin(), 5, NaturalSquares{});
 
-        copy(uv.begin(), uv.end(), ostream_iterator<int>(cout, " "));
+        copy(uv.begin(), uv.end(), ostream_iterator<int>{ cout, " " });
         cout << '\n';
     }
     // Displays:    1 4 9 16 25 0 0 0 0 0
