@@ -25,11 +25,11 @@
 
     int main()
     {
-        std::ofstream one("one");
-        std::ofstream two("two");
+        std::ofstream one{ "one" };
+        std::ofstream two{ "two" };
 
-        Reference ref1(one);        // ref1/ref2 hold references to
-        Reference ref2(two);        // the streams
+        Reference ref1{ one };          // ref1/ref2 hold references to
+        Reference ref2{ two };          // the streams
 
         ref1.out() << "hello to 1\n";   // generate some output
         ref2.out() << "hello to 2\n";
