@@ -1,8 +1,8 @@
     Strings::Strings(Strings &&tmp)
     :
-        d_memory(tmp.d_memory),
+        d_string(tmp.d_string),
         d_size(tmp.d_size),
         d_capacity(tmp.d_capacity)
     {
-        tmp.d_memory = 0;
+        tmp.d_string = 0;
     }
