@@ -8,7 +8,7 @@ void threadFun(std::string const &text)
     for (size_t iter = 1; iter != 6; ++iter)
     {
         std::cout << text << '\n';
-        sstd::this_thread::sleep_for(std::chrono::seconds(1));
+        std::this_thread::sleep_for(std::chrono::seconds(1));
     }
 }
 
